@@ -16,7 +16,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#if !defined(LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H) && !defined(LIBXFCE4PANEL_COMPILATION)
+#if !defined(_LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H) && !defined(LIBXFCE4PANEL_COMPILATION)
 #error "Only <libxfce4panel/libxfce4panel.h> can be included directly, this file may disappear or change contents"
 #endif
 
@@ -34,7 +34,7 @@ G_BEGIN_DECLS
  *
  * Since: 4.8
  **/
-#define LIBXFCE4PANEL_VERSION ("4.17.3")
+#define LIBXFCE4PANEL_VERSION ("4.18.1")
 
 /**
  * LIBXFCE4PANEL_MAJOR_VERSION:
@@ -58,7 +58,7 @@ G_BEGIN_DECLS
  * 
  * Since: 4.8
  **/
-#define LIBXFCE4PANEL_MINOR_VERSION (17)
+#define LIBXFCE4PANEL_MINOR_VERSION (18)
 
 /**
  * LIBXFCE4PANEL_MICRO_VERSION:
@@ -70,7 +70,7 @@ G_BEGIN_DECLS
  * 
  * Since: 4.8
  **/
-#define LIBXFCE4PANEL_MICRO_VERSION (3)
+#define LIBXFCE4PANEL_MICRO_VERSION (1)
 
 /**
  * LIBXFCE4PANEL_CHECK_VERSION:
