@@ -431,7 +431,8 @@ directory_menu_plugin_size_changed (XfcePanelPlugin *panel_plugin,
   size /= xfce_panel_plugin_get_nrows (panel_plugin);
   gtk_widget_set_size_request (GTK_WIDGET (panel_plugin), size, size);
   icon_size = xfce_panel_plugin_get_icon_size (panel_plugin);
-  xfce_panel_set_image_from_source (GTK_IMAGE (plugin->icon), plugin->icon_name, NULL, icon_size);
+  xfce_panel_set_image_from_source (GTK_IMAGE (plugin->icon), plugin->icon_name, NULL, icon_size,
+                                    gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
 
   return TRUE;
 }
@@ -481,7 +482,8 @@ directory_menu_plugin_configure_plugin_icon_chooser (GtkWidget           *button
 
       image = gtk_image_new ();
       xfce_panel_set_image_from_source (GTK_IMAGE (image), plugin->icon_name,
-                                        NULL, DIALOG_ICON_SIZE);
+                                        NULL, DIALOG_ICON_SIZE,
+                                        gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
       gtk_container_remove (GTK_CONTAINER (button), gtk_bin_get_child (GTK_BIN (button)));
       gtk_container_add (GTK_CONTAINER (button), image);
       gtk_widget_show (image);
@@ -522,7 +524,8 @@ directory_menu_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 
   image = gtk_image_new ();
   xfce_panel_set_image_from_source (GTK_IMAGE (image), plugin->icon_name,
-                                    NULL, DIALOG_ICON_SIZE);
+                                    NULL, DIALOG_ICON_SIZE,
+                                    gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
   gtk_container_add (GTK_CONTAINER (object), image);
   gtk_widget_show (image);
 
@@ -1274,15 +1277,6 @@ directory_menu_plugin_menu_load (GtkWidget           *menu,
 
 
 
-static gboolean
-directory_menu_plugin_menu_reposition (gpointer data)
-{
-  gtk_menu_reposition (data);
-  return FALSE;
-}
-
-
-
 static void
 directory_menu_plugin_menu (GtkWidget           *button,
                             DirectoryMenuPlugin *plugin)
@@ -1297,8 +1291,6 @@ directory_menu_plugin_menu (GtkWidget           *button,
       && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     return;
 
-  menu = gtk_menu_new ();
-
   /* Panel plugin remote events don't send actual GdkEvents, so construct a minimal one so that
    * gtk_menu_popup_at_pointer/rect can extract a location correctly from a GdkWindow */
   if (gtk_get_current_event () == NULL)
@@ -1306,12 +1298,9 @@ directory_menu_plugin_menu (GtkWidget           *button,
       event = g_slice_new0 (GdkEventButton);
       event->type = GDK_BUTTON_PRESS;
       event->window = gdk_get_default_root_window ();
-
-      /* reposition menu if popped up at widget and panel was autohidden when it was shown */
-      if (button != NULL)
-        g_idle_add (directory_menu_plugin_menu_reposition, menu);
     }
 
+  menu = gtk_menu_new ();
   g_signal_connect (G_OBJECT (menu), "deactivate",
       G_CALLBACK (directory_menu_plugin_deactivate), plugin);
 
