@@ -228,6 +228,18 @@ window_menu_plugin_class_init (WindowMenuPluginClass *klass)
 
 
 
+static void
+window_menu_plugin_scale_factor (WindowMenuPlugin *plugin)
+{
+  gint scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (plugin));
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  wnck_set_default_icon_size (WNCK_DEFAULT_ICON_SIZE * scale_factor);
+  wnck_set_default_mini_icon_size (WNCK_DEFAULT_MINI_ICON_SIZE * scale_factor);
+G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
+
+
 static void
 window_menu_plugin_init (WindowMenuPlugin *plugin)
 {
@@ -253,6 +265,9 @@ window_menu_plugin_init (WindowMenuPlugin *plugin)
   plugin->icon = gtk_image_new_from_icon_name ("user-desktop", GTK_ICON_SIZE_BUTTON);
   gtk_container_add (GTK_CONTAINER (plugin->button), plugin->icon);
   gtk_widget_show (plugin->icon);
+
+  window_menu_plugin_scale_factor (plugin);
+  g_signal_connect (plugin, "notify::scale-factor", G_CALLBACK (window_menu_plugin_scale_factor), NULL);
 }
 
 
@@ -636,7 +651,7 @@ window_menu_plugin_set_icon (WindowMenuPlugin *plugin,
 
   icon_size = xfce_panel_plugin_get_icon_size (XFCE_PANEL_PLUGIN (plugin));
   scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (plugin));
-  if (icon_size * scale_factor <= 31)
+  if (icon_size < WNCK_DEFAULT_ICON_SIZE)
     pixbuf = wnck_window_get_mini_icon (window);
   else
     pixbuf = wnck_window_get_icon (window);
@@ -1406,15 +1421,6 @@ window_menu_plugin_menu_new (WindowMenuPlugin *plugin)
 
 
 
-static gboolean
-window_menu_plugin_menu_reposition (gpointer data)
-{
-  gtk_menu_reposition (data);
-  return FALSE;
-}
-
-
-
 static void
 window_menu_plugin_menu (GtkWidget        *button,
                          WindowMenuPlugin *plugin)
@@ -1429,8 +1435,6 @@ window_menu_plugin_menu (GtkWidget        *button,
       && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     return;
 
-  menu = window_menu_plugin_menu_new (plugin);
-
   /* Panel plugin remote events don't send actual GdkEvents, so construct a minimal one so that
    * gtk_menu_popup_at_pointer/rect can extract a location correctly from a GdkWindow */
   if (gtk_get_current_event () == NULL)
@@ -1438,13 +1442,10 @@ window_menu_plugin_menu (GtkWidget        *button,
       event = g_slice_new0 (GdkEventButton);
       event->type = GDK_BUTTON_PRESS;
       event->window = gdk_get_default_root_window ();
-
-      /* reposition menu if popped up at widget and panel was autohidden when it was shown */
-      if (button != NULL)
-        g_idle_add (window_menu_plugin_menu_reposition, menu);
     }
 
   /* popup the menu */
+  menu = window_menu_plugin_menu_new (plugin);
   g_signal_connect (G_OBJECT (menu), "deactivate",
       G_CALLBACK (window_menu_plugin_menu_deactivate), plugin);
 
